Computes the sum of pairwise Euclidean distances between cell type expression profiles. Higher values indicate more distinct profiles.
Usage
compute_distance(data, use_cpp = getOption("darwin.use_cpp", TRUE))Computes the sum of pairwise Euclidean distances between cell type expression profiles. Higher values indicate more distinct profiles.
compute_distance(data, use_cpp = getOption("darwin.use_cpp", TRUE))